Index: /trunk/src/VBox/Main/src-server/ApplianceImplImport.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/ApplianceImplImport.cpp	(revision 68157)
+++ /trunk/src/VBox/Main/src-server/ApplianceImplImport.cpp	(revision 68158)
@@ -3466,6 +3466,8 @@
         /** @todo r=klaus add support for arbitrary USB controller types, this can't handle
          *  multiple controllers due to its design anyway */
         /* usually the OHCI controller is enabled already, need to check */
         bool fOHCIEnabled = false;
+        bool fXHCIEnabled = false;
         settings::USBControllerList &llUSBControllers = config.hardwareMachine.usbSettings.llUSBControllers;
         settings::USBControllerList::iterator it;
@@ -3473,11 +3475,10 @@
         {
             if (it->enmType == USBControllerType_OHCI)
-            {
                 fOHCIEnabled = true;
-                break;
-            }
+            if (it->enmType == USBControllerType_XHCI)
+                fXHCIEnabled = true;
         }
 
-        if (!fOHCIEnabled)
+        if (!fXHCIEnabled && !fOHCIEnabled)
         {
             settings::USBController ctrl;
@@ -3466,6 +3466,8 @@
         /** @todo r=klaus add support for arbitrary USB controller types, this can't handle
          *  multiple controllers due to its design anyway */
-        /* usually the OHCI controller is enabled already, need to check */
+        /* Usually the OHCI controller is enabled already, need to check. But
+         * do this only if there is no xHCI controller. */
         bool fOHCIEnabled = false;
